@@ -57,10 +57,8 @@ SendLaterAgent::SendLaterAgent(const QString &id)
     connect(mManager, &SendLaterManager::needUpdateConfigDialogBox, this, &SendLaterAgent::needUpdateConfigDialogBox);
     new SendLaterAgentAdaptor(this);
     KDBusConnectionPool::threadConnection().registerObject(QStringLiteral("/SendLaterAgent"), this, QDBusConnection::ExportAdaptors);
-    QString service = QStringLiteral("org.freedesktop.Akonadi.SendLaterAgent");
-    if (Akonadi::ServerManager::hasInstanceIdentifier()) {
-        service += QLatin1Char('.') + Akonadi::ServerManager::instanceIdentifier();
-    }
+
+    const QString service = Akonadi::ServerManager::self()->agentServiceName(Akonadi::ServerManager::Agent, QStringLiteral("akonadi_sendlater_agent"));
 
     KDBusConnectionPool::threadConnection().registerService(service);
 
@@ -137,16 +135,6 @@ bool SendLaterAgent::enabledAgent() const
 }
 
 void SendLaterAgent::configure(WId windowId)
-{
-    showConfigureDialog(static_cast<qlonglong>(windowId));
-}
-
-void SendLaterAgent::slotSendNow(Akonadi::Item::Id id)
-{
-    mManager->sendNow(id);
-}
-
-void SendLaterAgent::showConfigureDialog(qlonglong windowId)
 {
     QPointer<SendLaterConfigureDialog> dialog = new SendLaterConfigureDialog();
     if (windowId) {
@@ -166,6 +154,11 @@ void SendLaterAgent::showConfigureDialog(qlonglong windowId)
     delete dialog;
 }
 
+void SendLaterAgent::slotSendNow(Akonadi::Item::Id id)
+{
+    mManager->sendNow(id);
+}
+
 void SendLaterAgent::itemsRemoved(const Akonadi::Item::List &items)
 {
     for (const Akonadi::Item &item : items) {
