@@ -70,7 +70,7 @@ void HandleClickedUrlJob::start()
         //TODO
     }
 
-    TemplateParser::TemplateParserJob *parser = new TemplateParser::TemplateParserJob(mMsg, TemplateParser::TemplateParserJob::NewMessage);
+    TemplateParser::TemplateParserJob *parser = new TemplateParser::TemplateParserJob(mMsg, TemplateParser::TemplateParserJob::NewMessage, this);
     connect(parser, &TemplateParser::TemplateParserJob::parsingDone, this, &HandleClickedUrlJob::slotOpenComposer);
     parser->setIdentityManager(KMKernel::self()->identityManager());
     parser->process(mMsg, mCurrentCollection.id());
