@@ -376,30 +376,31 @@ private:
     Result execute() override;
 };
 
+struct KMPrintCommandInfo
+{
+    Akonadi::Item mMsg;
+    QFont mOverrideFont;
+    QString mEncoding;
+    MessageViewer::Viewer::DisplayFormatMessage mFormat = MessageViewer::Viewer::UseGlobalSetting;
+    const MessageViewer::AttachmentStrategy *mAttachmentStrategy = nullptr;
+    MessageViewer::HeaderStylePlugin *mHeaderStylePlugin = nullptr;
+    bool mHtmlLoadExtOverride = false;
+    bool mUseFixedFont = false;
+    bool mPrintPreview = false;
+    bool mShowSignatureDetails = false;
+    bool mShowEncryptionDetails = false;
+};
+
 class KMPrintCommand : public KMCommand
 {
     Q_OBJECT
 
 public:
-    KMPrintCommand(QWidget *parent, const Akonadi::Item &msg, MessageViewer::HeaderStylePlugin *plugin = nullptr,
-                   MessageViewer::Viewer::DisplayFormatMessage format = MessageViewer::Viewer::UseGlobalSetting, bool htmlLoadExtOverride = false, bool useFixedFont = false,
-                   const QString &encoding = QString());
-
-    void setOverrideFont(const QFont &);
-    void setAttachmentStrategy(const MessageViewer::AttachmentStrategy *strategy);
-    void setPrintPreview(bool preview);
-
+    KMPrintCommand(QWidget *parent, const KMPrintCommandInfo &commandInfo);
 private:
     Result execute() override;
 
-    MessageViewer::HeaderStylePlugin *mHeaderStylePlugin = nullptr;
-    const MessageViewer::AttachmentStrategy *mAttachmentStrategy = nullptr;
-    QFont mOverrideFont;
-    QString mEncoding;
-    MessageViewer::Viewer::DisplayFormatMessage mFormat;
-    bool mHtmlLoadExtOverride = false;
-    bool mUseFixedFont = false;
-    bool mPrintPreview = false;
+    KMPrintCommandInfo mPrintCommandInfo;
 };
 
 class KMSetStatusCommand : public KMCommand
@@ -558,16 +559,48 @@ private:
     MessageList::Core::MessageItemSetReference mRef;
 };
 
-class KMTrashMsgCommand : public KMMoveCommand
+class KMTrashMsgCommand final : public KMCommand
 {
     Q_OBJECT
 
 public:
+    enum TrashOperation {
+        Unknown,
+        MoveToTrash,
+        Delete,
+        Both
+    };
+
     KMTrashMsgCommand(const Akonadi::Collection &srcFolder, const Akonadi::Item::List &msgList, MessageList::Core::MessageItemSetReference ref);
     KMTrashMsgCommand(const Akonadi::Collection &srcFolder, const Akonadi::Item &msg, MessageList::Core::MessageItemSetReference ref);
+    MessageList::Core::MessageItemSetReference refSet() const
+    {
+        return mRef;
+    }
+
+    TrashOperation operation() const;
+
+public Q_SLOTS:
+    void slotMoveCanceled();
+
+private Q_SLOTS:
+    void slotMoveResult(KJob *job);
+    void slotDeleteResult(KJob *job);
+Q_SIGNALS:
+    void moveDone(KMTrashMsgCommand *);
 
 private:
+    Result execute() override;
+    void completeMove(Result result);
+
     static Akonadi::Collection findTrashFolder(const Akonadi::Collection &srcFolder);
+
+    QMap<Akonadi::Collection, Akonadi::Item::List> mTrashFolders;
+    KPIM::ProgressItem *mMoveProgress = nullptr;
+    KPIM::ProgressItem *mDeleteProgress = nullptr;
+    MessageList::Core::MessageItemSetReference mRef;
+    QList<KJob *> mPendingMoves;
+    QList<KJob *> mPendingDeletes;
 };
 
 class KMResendMessageCommand : public KMCommand
