@@ -43,7 +43,6 @@ using KPIM::RecentAddresses;
 #include <mailtransport/transport.h>
 #include <mailtransport/transportmanager.h>
 #include <mailtransportakonadi/dispatcherinterface.h>
-#include <AkonadiCore/servermanager.h>
 
 #include <KSieveUi/SieveImapInstanceInterfaceManager>
 #include "mailserviceimpl.h"
@@ -94,12 +93,13 @@ using KMail::MailServiceImpl;
 #include <AkonadiCore/EntityTreeModel>
 #include <AkonadiCore/entitymimetypefiltermodel.h>
 #include <AkonadiCore/CollectionStatisticsJob>
+#include <AkonadiCore/ServerManager>
 
 #include <QNetworkConfigurationManager>
 #include <QDir>
 #include <QWidget>
 #include <QFileInfo>
-#include <QtDBus/QtDBus>
+#include <QtDBus>
 
 #include <MailCommon/ResourceReadConfigFile>
 
@@ -208,6 +208,8 @@ KMKernel::KMKernel(QObject *parent)
 
     connect(Akonadi::AgentManager::self(), &Akonadi::AgentManager::instanceRemoved, this, &KMKernel::slotInstanceRemoved);
 
+    connect(Akonadi::AgentManager::self(), &Akonadi::AgentManager::instanceAdded, this, &KMKernel::slotInstanceAdded);
+
     connect(PimCommon::NetworkManager::self()->networkConfigureManager(), &QNetworkConfigurationManager::onlineStateChanged,
             this, &KMKernel::slotSystemNetworkStatusChanged);
 
@@ -1117,8 +1119,8 @@ void KMKernel::cleanup()
     Akonadi::Collection trashCollection = CommonKernel->trashCollectionFolder();
     if (trashCollection.isValid()) {
         if (KMailSettings::self()->emptyTrashOnExit()) {
-            OrgFreedesktopAkonadiMailFilterAgentInterface mailFilterInterface(QStringLiteral("org.freedesktop.Akonadi.MailFilterAgent"), QStringLiteral(
-                                                                                  "/MailFilterAgent"), QDBusConnection::sessionBus(), this);
+            const auto service = Akonadi::ServerManager::self()->agentServiceName(Akonadi::ServerManager::Agent, QStringLiteral("akonadi_mailfilter_agent"));
+            OrgFreedesktopAkonadiMailFilterAgentInterface mailFilterInterface(service, QStringLiteral("/MailFilterAgent"), QDBusConnection::sessionBus(), this);
             if (mailFilterInterface.isValid()) {
                 mailFilterInterface.expunge(static_cast<qlonglong>(trashCollection.id()));
             } else {
@@ -1400,11 +1402,11 @@ static Akonadi::Collection::List collect_collections(const QAbstractItemModel *m
     QStack<QModelIndex> stack;
     stack.push(parent);
     while (!stack.isEmpty()) {
-        const auto idx = stack.pop();
+        const QModelIndex idx = stack.pop();
         if (idx.isValid()) {
             collections << model->data(idx, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
             for (int i = model->rowCount(idx) - 1; i >= 0; --i) {
-                stack.push(idx.child(i, 0));
+                stack.push(model->index(i, 0, idx));
             }
         }
     }
@@ -1816,6 +1818,17 @@ void KMKernel::slotInstanceRemoved(const Akonadi::AgentInstance &instance)
         mResourceCryptoSettingCache.remove(identifier);
     }
     mFolderArchiveManager->slotInstanceRemoved(instance);
+
+    if (MailCommon::Util::isMailAgent(instance)) {
+        Q_EMIT incomingAccountsChanged();
+    }
+}
+
+void KMKernel::slotInstanceAdded(const Akonadi::AgentInstance &instance)
+{
+    if (MailCommon::Util::isMailAgent(instance)) {
+        Q_EMIT incomingAccountsChanged();
+    }
 }
 
 void KMKernel::savePaneSelection()
