@@ -17,9 +17,11 @@
 class KMReaderWin;
 class QAction;
 class KJob;
+class ZoomLabelWidget;
 
 namespace KMail {
 class MessageActions;
+class TagActionManager;
 }
 
 namespace KMime {
@@ -86,6 +88,11 @@ private:
     void setupAccel();
     QAction *copyActionMenu(QMenu *menu);
     QAction *moveActionMenu(QMenu *menu);
+    void setZoomChanged(qreal zoomFactor);
+    void updateActions();
+    void slotSelectMoreMessageTagList();
+    void toggleMessageSetTag(const Akonadi::Item::List &select, const Akonadi::Tag &tag);
+    void slotUpdateMessageTagList(const Akonadi::Tag &tag);
 
     Akonadi::Collection mParentCollection;
     Akonadi::Item mMsg;
@@ -94,6 +101,8 @@ private:
     QAction *mSaveAtmAction = nullptr;
     KMail::MessageActions *mMsgActions = nullptr;
     KMReaderWin *mReaderWin = nullptr;
+    ZoomLabelWidget *mZoomLabelIndicator = nullptr;
+    KMail::TagActionManager *mTagActionManager = nullptr;
 };
 
 #endif /*KMReaderMainWin_h*/
