@@ -21,8 +21,8 @@
  *
  */
 
-#include "incompleteindexdialog.h"
 #include "searchwindow.h"
+#include "incompleteindexdialog.h"
 
 #include "MailCommon/FolderRequester"
 #include "kmcommands.h"
@@ -848,7 +848,9 @@ void SearchWindow::slotSaveAttachments()
 
 void SearchWindow::slotPrintMsg()
 {
-    KMCommand *command = new KMPrintCommand(this, selectedMessage());
+    KMPrintCommandInfo info;
+    info.mMsg = selectedMessage();
+    KMCommand *command = new KMPrintCommand(this, info);
     command->start();
 }
 
